@@ -19,10 +19,11 @@
 package org.apache.sedona.common;
 
 import java.io.IOException;
+import java.nio.ByteBuffer;
+import java.nio.ByteOrder;
 import javax.xml.parsers.ParserConfigurationException;
 import org.apache.sedona.common.enums.FileDataSplitter;
 import org.apache.sedona.common.enums.GeometryType;
-import org.apache.sedona.common.geometryObjects.Geography;
 import org.apache.sedona.common.utils.FormatUtils;
 import org.apache.sedona.common.utils.GeoHashDecoder;
 import org.locationtech.jts.geom.*;
@@ -45,10 +46,6 @@ public class Constructors {
     return new WKTReader(geometryFactory).read(wkt);
   }
 
-  public static Geography geogFromWKT(String wkt, int srid) throws ParseException {
-    return new Geography(geomFromWKT(wkt, srid));
-  }
-
   public static Geometry geomFromEWKT(String ewkt) throws ParseException {
     if (ewkt == null) {
       return null;
@@ -307,4 +304,21 @@ public class Constructors {
   public static Geometry geomFromKML(String kml) throws ParseException {
     return new KMLReader().read(kml);
   }
+
+  public static Geometry geomFromMySQL(byte[] binary) throws ParseException {
+    ByteBuffer buffer = ByteBuffer.wrap(binary);
+
+    buffer.order(ByteOrder.LITTLE_ENDIAN);
+    int srid = buffer.getInt();
+
+    byte[] wkb = new byte[buffer.remaining()];
+
+    buffer.get(wkb);
+
+    Geometry geom = geomFromWKB(wkb);
+
+    geom.setSRID(srid);
+
+    return geom;
+  }
 }
