@@ -94,4 +94,13 @@ public class Predicates {
   public static boolean relateMatch(String matrix1, String matrix2) {
     return IntersectionMatrix.matches(matrix1, matrix2);
   }
+
+  public static boolean knn(Geometry leftGeometry, Geometry rightGeometry, int k) {
+    throw new UnsupportedOperationException("KNN predicate is not supported");
+  }
+
+  public static boolean knn(
+      Geometry leftGeometry, Geometry rightGeometry, int k, boolean useSpheroid) {
+    throw new UnsupportedOperationException("KNN predicate is not supported");
+  }
 }
