@@ -25,13 +25,13 @@ import java.util.*;
 import javax.media.jai.RasterFactory;
 import org.apache.sedona.common.Functions;
 import org.apache.sedona.common.utils.RasterUtils;
+import org.geotools.api.geometry.BoundingBox;
+import org.geotools.api.referencing.FactoryException;
 import org.geotools.coverage.grid.GridCoverage2D;
 import org.geotools.coverage.grid.GridCoverageFactory;
-import org.geotools.geometry.Envelope2D;
 import org.geotools.geometry.jts.JTS;
+import org.geotools.geometry.jts.ReferencedEnvelope;
 import org.locationtech.jts.geom.*;
-import org.opengis.geometry.BoundingBox;
-import org.opengis.referencing.FactoryException;
 
 public class Rasterization {
   protected static List<Object> rasterize(
@@ -50,9 +50,9 @@ public class Rasterization {
       throw new IllegalArgumentException("Geometry does not intersect Raster.");
     }
 
-    Envelope2D rasterExtent = raster.getEnvelope2D();
+    ReferencedEnvelope rasterExtent = raster.getEnvelope2D();
 
-    Envelope2D geomExtent = rasterizeGeomExtent(geom, raster, metadata, allTouched);
+    ReferencedEnvelope geomExtent = rasterizeGeomExtent(geom, raster, metadata, allTouched);
 
     RasterizationParams params =
         calculateRasterizationParams(raster, useGeometryExtent, metadata, geomExtent, pixelType);
@@ -82,7 +82,7 @@ public class Rasterization {
       double[] metadata,
       Geometry geom,
       RasterizationParams params,
-      Envelope2D geomExtent,
+      ReferencedEnvelope geomExtent,
       double value,
       boolean allTouched)
       throws FactoryException {
@@ -118,13 +118,13 @@ public class Rasterization {
 
     for (int i = 0; i < geom.getNumGeometries(); i++) {
       Geometry subGeom = geom.getGeometryN(i);
-      Envelope2D subGeomExtent = rasterizeGeomExtent(subGeom, raster, metadata, allTouched);
+      ReferencedEnvelope subGeomExtent = rasterizeGeomExtent(subGeom, raster, metadata, allTouched);
       rasterizeGeometry(raster, metadata, subGeom, params, subGeomExtent, value, allTouched);
     }
   }
 
   private static void rasterizePoint(
-      Geometry geom, RasterizationParams params, Envelope2D geomExtent, double value) {
+      Geometry geom, RasterizationParams params, ReferencedEnvelope geomExtent, double value) {
 
     int startX = (int) Math.round(((geomExtent.getMinX() - params.upperLeftX) / params.scaleX));
     int startY = (int) Math.round(((geomExtent.getMinY() - params.upperLeftY) / params.scaleY));
@@ -157,7 +157,7 @@ public class Rasterization {
   }
 
   private static void rasterizeLineString(
-      Geometry geom, RasterizationParams params, double value, Envelope2D geomExtent) {
+      Geometry geom, RasterizationParams params, double value, ReferencedEnvelope geomExtent) {
     for (int i = 0; i < geom.getNumGeometries(); i++) {
       LineString line = (LineString) geom.getGeometryN(i);
       Coordinate[] coords = line.getCoordinates();
@@ -231,7 +231,7 @@ public class Rasterization {
   }
 
   private static LineSegment clipSegmentToRasterBounds(
-      Coordinate p1, Coordinate p2, Envelope2D geomExtent) {
+      Coordinate p1, Coordinate p2, ReferencedEnvelope geomExtent) {
     double minX = geomExtent.getMinX();
     double maxX = geomExtent.getMaxX();
     double minY = geomExtent.getMinY();
@@ -303,7 +303,7 @@ public class Rasterization {
     return x >= minX && x <= maxX && y >= minY && y <= maxY;
   }
 
-  protected static Envelope2D rasterizeGeomExtent(
+  protected static ReferencedEnvelope rasterizeGeomExtent(
       Geometry geom, GridCoverage2D raster, double[] metadata, boolean allTouched) {
 
     if (Objects.equals(geom.getGeometryType(), "MultiLineString")) {
@@ -313,8 +313,8 @@ public class Rasterization {
       allTouched = true;
     }
 
-    Envelope2D rasterExtent =
-        JTS.getEnvelope2D(geom.getEnvelopeInternal(), raster.getCoordinateReferenceSystem2D());
+    ReferencedEnvelope rasterExtent =
+        new ReferencedEnvelope(geom.getEnvelopeInternal(), raster.getCoordinateReferenceSystem2D());
 
     // Using BigDecimal to avoid floating point errors
     BigDecimal upperLeftX = BigDecimal.valueOf(metadata[0]);
@@ -387,13 +387,13 @@ public class Rasterization {
     alignedMaxY = Math.min(alignedMaxY, originalMaxY);
 
     // Create the aligned raster extent
-    Envelope2D alignedRasterExtent =
-        new Envelope2D(
-            rasterExtent.getCoordinateReferenceSystem(),
+    ReferencedEnvelope alignedRasterExtent =
+        ReferencedEnvelope.rect(
             alignedMinX,
             alignedMinY,
             alignedMaxX - alignedMinX,
-            alignedMaxY - alignedMinY);
+            alignedMaxY - alignedMinY,
+            rasterExtent.getCoordinateReferenceSystem());
 
     return alignedRasterExtent;
   }
@@ -402,7 +402,7 @@ public class Rasterization {
       GridCoverage2D raster,
       boolean useGeometryExtent,
       double[] metadata,
-      Envelope2D geomExtent,
+      ReferencedEnvelope geomExtent,
       String pixelType) {
 
     double upperLeftX = 0;
@@ -474,7 +474,7 @@ public class Rasterization {
   public static void rasterizePolygon(
       Geometry geom,
       RasterizationParams params,
-      Envelope2D geomExtent,
+      ReferencedEnvelope geomExtent,
       double value,
       boolean allTouched) {
     if (!(geom instanceof Polygon)) {
@@ -512,7 +512,7 @@ public class Rasterization {
       Polygon polygon,
       RasterizationParams params,
       double value,
-      Envelope2D geomExtent,
+      ReferencedEnvelope geomExtent,
       boolean allTouched) {
 
     Map<Double, TreeSet<Double>> scanlineIntersections = new HashMap<>();
@@ -549,14 +549,14 @@ public class Rasterization {
         // Calculate scan line limits to iterate between for each segment
         // Using BigDecimal to avoid floating point errors
         double yStart =
-            Math.ceil(
+            Math.round(
                 (BigDecimal.valueOf(params.upperLeftY)
                         .subtract(BigDecimal.valueOf(worldP1.y))
                         .divide(BigDecimal.valueOf(params.scaleY), RoundingMode.CEILING))
                     .doubleValue());
 
         double yEnd =
-            Math.floor(
+            Math.round(
                 (BigDecimal.valueOf(params.upperLeftY)
                         .subtract(BigDecimal.valueOf(worldP2.y))
                         .divide(BigDecimal.valueOf(params.scaleY), RoundingMode.FLOOR))
@@ -581,17 +581,14 @@ public class Rasterization {
           }
         } else {
           double slope = (worldP2.y - worldP1.y) / (worldP2.x - worldP1.x);
-          //        System.out.println("slope: " + slope);
-
+          double xMin = (geomExtent.getMinX() - params.upperLeftX) / params.scaleX;
+          double xMax = (geomExtent.getMaxX() - params.upperLeftX) / params.scaleX;
           for (double y = yStart; y >= yEnd; y--) {
             double xIntercept = p1X + ((p1Y - y) / slope);
-            if ((xIntercept < 0) || (xIntercept >= params.writableRaster.getWidth())) {
-              continue; // skip xIntercepts outside geomExtent
+            if ((xIntercept < xMin) || (xIntercept >= xMax)) {
+              continue; // Skip xIntercepts outside geomExtent
             }
-            if (!scanlineIntersections.containsKey(y)) {
-              scanlineIntersections.put(y, new TreeSet<>());
-            }
-            scanlineIntersections.get(y).add(xIntercept);
+            scanlineIntersections.computeIfAbsent(y, k -> new TreeSet<>()).add(xIntercept);
           }
         }
       }
