@@ -23,13 +23,13 @@ import static org.junit.Assert.assertThrows;
 
 import java.io.IOException;
 import org.apache.sedona.common.Functions;
+import org.geotools.api.referencing.FactoryException;
+import org.geotools.api.referencing.operation.TransformException;
 import org.geotools.coverage.grid.GridCoverage2D;
 import org.junit.Test;
 import org.locationtech.jts.geom.Coordinate;
 import org.locationtech.jts.geom.Envelope;
 import org.locationtech.jts.geom.Geometry;
-import org.opengis.referencing.FactoryException;
-import org.opengis.referencing.operation.TransformException;
 
 public class GeometryFunctionsTest extends RasterTestBase {
 
