@@ -1,19 +1,19 @@
-#  Licensed to the Apache Software Foundation (ASF) under one
-#  or more contributor license agreements.  See the NOTICE file
-#  distributed with this work for additional information
-#  regarding copyright ownership.  The ASF licenses this file
-#  to you under the Apache License, Version 2.0 (the
-#  "License"); you may not use this file except in compliance
-#  with the License.  You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-#    http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-#  Unless required by applicable law or agreed to in writing,
-#  software distributed under the License is distributed on an
-#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-#  KIND, either express or implied.  See the License for the
-#  specific language governing permissions and limitations
-#  under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 import pytest
 from pyspark.sql.functions import expr
 from pyspark.sql.types import StringType, StructType
@@ -25,11 +25,12 @@ from shapely.geometry import (
     MultiPolygon,
     Point,
     Polygon,
+    LinearRing,
 )
 from shapely.wkt import loads as wkt_loads
 from tests.test_base import TestBase
 
-from sedona.sql.types import GeometryType
+from sedona.spark.sql.types import GeometryType
 
 
 class TestGeometrySerde(TestBase):
@@ -102,6 +103,22 @@ class TestGeometrySerde(TestBase):
         ).take(1)[0][0]
         assert geom.equals_exact(returned_geom, 1e-6)
 
+    @pytest.mark.parametrize(
+        "geom",
+        [
+            LinearRing(),
+            LinearRing([(0, 0), (1, 0), (1, 1), (0, 1), (0, 0)]),
+        ],
+    )
+    def test_linearring_spark_serde(self, geom):
+        returned_geom = TestGeometrySerde.spark.createDataFrame(
+            [(geom,)], StructType().add("geom", GeometryType())
+        ).take(1)[0][0]
+        # Shapely < 2.0.0 returns an empty GeometryCollection instead
+        if not geom.is_empty:
+            assert isinstance(returned_geom, LineString)
+        assert geom.equals(returned_geom)
+
     @pytest.mark.parametrize(
         "wkt",
         [
@@ -143,6 +160,8 @@ class TestGeometrySerde(TestBase):
             "MULTIPOLYGON (EMPTY, EMPTY)",
             "GEOMETRYCOLLECTION (POINT (10 20), POINT EMPTY, LINESTRING (10 20, 30 40))",
             "GEOMETRYCOLLECTION (MULTIPOINT EMPTY, MULTILINESTRING EMPTY, MULTIPOLYGON EMPTY, GEOMETRYCOLLECTION EMPTY)",
+            "LINEARRING EMPTY",
+            "LINEARRING (-1 -1, -1 1, 1 1, 1 -1, -1 -1)",
         ],
     )
     def test_spark_serde_compatibility_with_scala(self, wkt):
@@ -181,6 +200,7 @@ class TestGeometrySerde(TestBase):
             "MULTIPOLYGON ZM (((10 10 10 1, 20 20 10 1, 20 10 10 1, 10 10 10 1)), "
             + "((0 0 0 1, 0 10 0 1, 10 10 0 1, 10 0 0 1, 0 0 0 1), (1 1 0 1, 1 2 0 1, 2 2 0 1, 2 1 0 1, 1 1 0 1)))",
             "GEOMETRYCOLLECTION (POINT ZM (10 20 30 1), LINESTRING ZM (10 20 30 1, 40 50 60 1))",
+            "LINEARRING ZM (0 0 0 1, 0 0 1 0, 0 1 0 0, 1 0 0 0, 0 0 0 1)",
         ],
     )
     def test_spark_serde_on_4d_geoms(self, wkt):
@@ -205,6 +225,7 @@ class TestGeometrySerde(TestBase):
             "MULTIPOLYGON M (((10 10 10, 20 20 10, 20 10 10, 10 10 10)), "
             + "((0 0 0, 0 10 0, 10 10 0, 10 0 0, 0 0 0), (1 1 0, 1 2 0, 2 2 0, 2 1 0, 1 1 0)))",
             "GEOMETRYCOLLECTION (POINT M (10 20 30), LINESTRING M (10 20 30, 40 50 60))",
+            "LINEARRING M (0 0 0, 1 0 0, 0 1 0, 0 0 1, 0 0 0)",
         ],
     )
     def test_spark_serde_on_xym_geoms(self, wkt):
