@@ -1,20 +1,22 @@
-#  Licensed to the Apache Software Foundation (ASF) under one
-#  or more contributor license agreements.  See the NOTICE file
-#  distributed with this work for additional information
-#  regarding copyright ownership.  The ASF licenses this file
-#  to you under the Apache License, Version 2.0 (the
-#  "License"); you may not use this file except in compliance
-#  with the License.  You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-#    http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-#  Unless required by applicable law or agreed to in writing,
-#  software distributed under the License is distributed on an
-#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-#  KIND, either express or implied.  See the License for the
-#  specific language governing permissions and limitations
-#  under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
+import pytest
+import shapely
 from shapely.geometry import (
     GeometryCollection,
     LineString,
@@ -27,7 +29,7 @@ from shapely.geometry import (
 from shapely.geometry.base import BaseGeometry
 from shapely.wkt import loads as wkt_loads
 
-from sedona.utils import geometry_serde
+from sedona.spark.utils import geometry_serde
 
 
 class TestGeomSerdeSpeedup:
@@ -135,6 +137,15 @@ class TestGeomSerdeSpeedup:
         ]
         self._test_serde_roundtrip(geometry_collections)
 
+    @pytest.mark.skipif(
+        shapely.__version__ < "2", reason="SRID functions require Shapely >= 2.0"
+    )
+    def test_srid_roundtrip(self):
+        point = wkt_loads("POINT (1 2)")
+        point = shapely.set_srid(point, 1000)
+        point2 = TestGeomSerdeSpeedup.serde_roundtrip(point)
+        assert shapely.get_srid(point2) == 1000
+
     @staticmethod
     def _test_serde_roundtrip(geoms):
         for geom in geoms:
