@@ -18,21 +18,24 @@
  */
 package org.apache.sedona.core.formatMapper.shapefileParser.parseUtils.shp;
 
-import java.io.IOException;
 import org.locationtech.jts.geom.Coordinate;
+import org.locationtech.jts.geom.CoordinateXYM;
+import org.locationtech.jts.geom.CoordinateXYZM;
 import org.locationtech.jts.geom.Geometry;
 import org.locationtech.jts.geom.GeometryFactory;
-import org.locationtech.jts.geom.Point;
 
 public class PointParser extends ShapeParser {
 
+  private final ShapeType shapeType;
+
   /**
    * create a parser that can abstract a Point from input source with given GeometryFactory.
    *
    * @param geometryFactory the geometry factory
    */
-  public PointParser(GeometryFactory geometryFactory) {
+  public PointParser(GeometryFactory geometryFactory, ShapeType shapeType) {
     super(geometryFactory);
+    this.shapeType = shapeType;
   }
 
   /**
@@ -40,13 +43,32 @@ public class PointParser extends ShapeParser {
    *
    * @param reader the reader
    * @return the geometry
-   * @throws IOException Signals that an I/O exception has occurred.
    */
   @Override
   public Geometry parseShape(ShapeReader reader) {
     double x = reader.readDouble();
     double y = reader.readDouble();
-    Point point = geometryFactory.createPoint(new Coordinate(x, y));
-    return point;
+
+    if (shapeType == ShapeType.POINTZ) {
+      // For POINTZ, read both Z and M values
+      double z = reader.readDouble();
+      double m = reader.readDouble();
+      if (isNoData(m)) {
+        return geometryFactory.createPoint(new Coordinate(x, y, z));
+      } else {
+        return geometryFactory.createPoint(new CoordinateXYZM(x, y, z, m));
+      }
+    } else if (shapeType == ShapeType.POINTM) {
+      // For POINTM, read M value only
+      double m = reader.readDouble(); // M value read but not currently used
+      if (isNoData(m)) {
+        return geometryFactory.createPoint(new Coordinate(x, y));
+      } else {
+        return geometryFactory.createPoint(new CoordinateXYM(x, y, m));
+      }
+    } else {
+      // Regular POINT with just XY coordinates
+      return geometryFactory.createPoint(new Coordinate(x, y));
+    }
   }
 }
