@@ -22,6 +22,7 @@ import org.apache.spark.sql.expressions.Aggregator
 import org.apache.spark.sql.sedona_sql.expressions.collect.ST_Collect
 import org.apache.spark.sql.sedona_sql.expressions.raster._
 import org.apache.spark.sql.sedona_sql.expressions._
+import org.apache.spark.sql.sedona_sql.expressions.geography.{ST_GeogCollFromText, ST_GeogFromEWKB, ST_GeogFromEWKT, ST_GeogFromGeoHash, ST_GeogFromText, ST_GeogFromWKB, ST_GeogFromWKT, ST_GeogToGeometry, ST_GeomToGeography}
 import org.locationtech.jts.geom.Geometry
 import org.locationtech.jts.operation.buffer.BufferParameters
 
@@ -29,6 +30,8 @@ object Catalog extends AbstractCatalog {
 
   override val expressions: Seq[FunctionDescription] = Seq(
     // Expression for vectors
+    function[ExpandAddress](),
+    function[ParseAddress](),
     function[GeometryType](),
     function[ST_LabelPoint](),
     function[ST_PointFromText](),
@@ -41,6 +44,10 @@ object Catalog extends AbstractCatalog {
     function[ST_GeometryFromText](0),
     function[ST_LineFromText](),
     function[ST_GeogFromWKT](0),
+    function[ST_GeogFromText](0),
+    function[ST_GeogFromWKB](0),
+    function[ST_GeogFromEWKB](0),
+    function[ST_GeogFromEWKT](),
     function[ST_GeomFromWKT](0),
     function[ST_GeomFromEWKT](),
     function[ST_GeomFromWKB](),
@@ -171,6 +178,7 @@ object Catalog extends AbstractCatalog {
     function[ST_LongestLine](),
     function[ST_SubDivideExplode](),
     function[ST_SubDivide](),
+    function[ST_Segmentize](),
     function[ST_MakeLine](),
     function[ST_Polygon](),
     function[ST_Polygonize](),
@@ -180,6 +188,7 @@ object Catalog extends AbstractCatalog {
     function[ST_GeoHash](),
     function[ST_GeomFromGeoHash](null),
     function[ST_PointFromGeoHash](null),
+    function[ST_GeogFromGeoHash](null),
     function[ST_Collect](),
     function[ST_Multi](),
     function[ST_PointOnSurface](),
@@ -205,6 +214,8 @@ object Catalog extends AbstractCatalog {
     function[ST_MPolyFromText](0),
     function[ST_MLineFromText](0),
     function[ST_GeomCollFromText](0),
+    function[ST_GeogCollFromText](0),
+    function[ST_GeomFromMySQL](),
     function[ST_Split](),
     function[ST_S2CellIDs](),
     function[ST_S2ToGeom](),
@@ -341,7 +352,9 @@ object Catalog extends AbstractCatalog {
     function[ST_LocalOutlierFactor](),
     function[ST_GLocal](),
     function[ST_BinaryDistanceBandColumn](),
-    function[ST_WeightedDistanceBandColumn]())
+    function[ST_WeightedDistanceBandColumn](),
+    function[ST_GeogToGeometry](),
+    function[ST_GeomToGeography]())
 
   val aggregateExpressions: Seq[Aggregator[Geometry, _, _]] =
     Seq(new ST_Envelope_Aggr, new ST_Intersection_Aggr, new ST_Union_Aggr())
