@@ -24,21 +24,21 @@ import org.apache.spark.sql.sedona_sql.expressions.InferredExpression
 import org.apache.spark.sql.sedona_sql.expressions.InferrableFunctionConverter._
 import org.apache.spark.sql.sedona_sql.expressions.InferrableRasterTypes._
 
-case class RS_ConvexHull(inputExpressions: Seq[Expression])
+private[apache] case class RS_ConvexHull(inputExpressions: Seq[Expression])
     extends InferredExpression(GeometryFunctions.convexHull _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_Envelope(inputExpressions: Seq[Expression])
+private[apache] case class RS_Envelope(inputExpressions: Seq[Expression])
     extends InferredExpression(GeometryFunctions.envelope _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_MinConvexHull(inputExpressions: Seq[Expression])
+private[apache] case class RS_MinConvexHull(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction2(GeometryFunctions.minConvexHull),
       inferrableFunction1(GeometryFunctions.minConvexHull)) {
