@@ -24,63 +24,63 @@ import org.apache.spark.sql.sedona_sql.expressions.InferrableFunctionConverter._
 import org.apache.spark.sql.sedona_sql.expressions.InferrableRasterTypes._
 import org.apache.spark.sql.sedona_sql.expressions.InferredExpression
 
-case class RS_NumBands(inputExpressions: Seq[Expression])
+private[apache] case class RS_NumBands(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.numBands _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_SRID(inputExpressions: Seq[Expression])
+private[apache] case class RS_SRID(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.srid _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_Width(inputExpressions: Seq[Expression])
+private[apache] case class RS_Width(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getWidth _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_UpperLeftX(inputExpressions: Seq[Expression])
+private[apache] case class RS_UpperLeftX(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getUpperLeftX _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_UpperLeftY(inputExpressions: Seq[Expression])
+private[apache] case class RS_UpperLeftY(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getUpperLeftY _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_Height(inputExpressions: Seq[Expression])
+private[apache] case class RS_Height(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getHeight _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_ScaleX(inputExpressions: Seq[Expression])
+private[apache] case class RS_ScaleX(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getScaleX _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_ScaleY(inputExpressions: Seq[Expression])
+private[apache] case class RS_ScaleY(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getScaleY _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_GeoReference(inputExpressions: Seq[Expression])
+private[apache] case class RS_GeoReference(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction2(RasterAccessors.getGeoReference),
       inferrableFunction1(RasterAccessors.getGeoReference)) {
@@ -89,49 +89,49 @@ case class RS_GeoReference(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_Rotation(inputExpressions: Seq[Expression])
+private[apache] case class RS_Rotation(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getRotation _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_SkewX(inputExpressions: Seq[Expression])
+private[apache] case class RS_SkewX(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getSkewX _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]): Expression = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_SkewY(inputExpressions: Seq[Expression])
+private[apache] case class RS_SkewY(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getSkewY _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]): Expression = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_RasterToWorldCoordX(inputExpressions: Seq[Expression])
+private[apache] case class RS_RasterToWorldCoordX(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getWorldCoordX _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_RasterToWorldCoordY(inputExpressions: Seq[Expression])
+private[apache] case class RS_RasterToWorldCoordY(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getWorldCoordY _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_RasterToWorldCoord(inputExpressions: Seq[Expression])
+private[apache] case class RS_RasterToWorldCoord(inputExpressions: Seq[Expression])
     extends InferredExpression(RasterAccessors.getWorldCoord _) {
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
   }
 }
 
-case class RS_WorldToRasterCoord(inputExpressions: Seq[Expression])
+private[apache] case class RS_WorldToRasterCoord(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction3(RasterAccessors.getGridCoord),
       inferrableFunction2(RasterAccessors.getGridCoord)) {
@@ -140,7 +140,7 @@ case class RS_WorldToRasterCoord(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_WorldToRasterCoordX(inputExpressions: Seq[Expression])
+private[apache] case class RS_WorldToRasterCoordX(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction3(RasterAccessors.getGridCoordX),
       inferrableFunction2(RasterAccessors.getGridCoordX)) {
@@ -149,7 +149,7 @@ case class RS_WorldToRasterCoordX(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_WorldToRasterCoordY(inputExpressions: Seq[Expression])
+private[apache] case class RS_WorldToRasterCoordY(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction3(RasterAccessors.getGridCoordY),
       inferrableFunction2(RasterAccessors.getGridCoordY)) {
