@@ -24,7 +24,7 @@ import org.apache.spark.sql.sedona_sql.expressions.InferrableFunctionConverter._
 import org.apache.spark.sql.sedona_sql.expressions.InferrableRasterTypes._
 import org.apache.spark.sql.sedona_sql.expressions.InferredExpression
 
-case class RS_AsGeoTiff(inputExpressions: Seq[Expression])
+private[apache] case class RS_AsGeoTiff(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction3(RasterOutputs.asGeoTiff),
       inferrableFunction1(RasterOutputs.asGeoTiff)) {
@@ -33,7 +33,7 @@ case class RS_AsGeoTiff(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_AsArcGrid(inputExpressions: Seq[Expression])
+private[apache] case class RS_AsArcGrid(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction2(RasterOutputs.asArcGrid),
       inferrableFunction1(RasterOutputs.asArcGrid)) {
@@ -42,7 +42,7 @@ case class RS_AsArcGrid(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_AsPNG(inputExpressions: Seq[Expression])
+private[apache] case class RS_AsPNG(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction1(RasterOutputs.asPNG),
       inferrableFunction2(RasterOutputs.asPNG)) {
@@ -51,7 +51,7 @@ case class RS_AsPNG(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_AsBase64(inputExpressions: Seq[Expression])
+private[apache] case class RS_AsBase64(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction1(RasterOutputs.asBase64),
       inferrableFunction2(RasterOutputs.asBase64)) {
@@ -60,7 +60,7 @@ case class RS_AsBase64(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_AsMatrix(inputExpressions: Seq[Expression])
+private[apache] case class RS_AsMatrix(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction3(RasterOutputs.asMatrix),
       inferrableFunction2(RasterOutputs.asMatrix),
@@ -70,7 +70,7 @@ case class RS_AsMatrix(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_AsImage(inputExpressions: Seq[Expression])
+private[apache] case class RS_AsImage(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction2(RasterOutputs.createHTMLString),
       inferrableFunction1(RasterOutputs.createHTMLString)) {
