@@ -22,9 +22,9 @@ import org.apache.sedona.common.raster.RasterPredicates
 import org.apache.sedona.sql.utils.{GeometrySerializer, RasterSerializer}
 import org.apache.spark.sql.catalyst.InternalRow
 import org.apache.spark.sql.catalyst.expressions.codegen.CodegenFallback
-import org.apache.spark.sql.catalyst.expressions.{ExpectsInputTypes, Expression, NullIntolerant}
+import org.apache.spark.sql.catalyst.expressions.{ExpectsInputTypes, Expression}
 import org.apache.spark.sql.sedona_sql.UDT.{GeometryUDT, RasterUDT}
-import org.apache.spark.sql.sedona_sql.expressions.FoldableExpression
+import org.apache.spark.sql.sedona_sql.expressions.{FoldableExpression, NullIntolerantShim}
 import org.apache.spark.sql.types.{AbstractDataType, BooleanType, DataType}
 import org.geotools.coverage.grid.GridCoverage2D
 import org.locationtech.jts.geom.Geometry
@@ -33,7 +33,7 @@ abstract class RS_Predicate
     extends Expression
     with FoldableExpression
     with ExpectsInputTypes
-    with NullIntolerant {
+    with NullIntolerantShim {
   def inputExpressions: Seq[Expression]
 
   override def toString: String = s" **${this.getClass.getName}**  "
@@ -99,7 +99,7 @@ abstract class RS_Predicate
   def evalRasters(leftRaster: GridCoverage2D, rightRaster: GridCoverage2D): Boolean
 }
 
-case class RS_Intersects(inputExpressions: Seq[Expression])
+private[apache] case class RS_Intersects(inputExpressions: Seq[Expression])
     extends RS_Predicate
     with CodegenFallback {
 
@@ -118,7 +118,7 @@ case class RS_Intersects(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_Contains(inputExpressions: Seq[Expression])
+private[apache] case class RS_Contains(inputExpressions: Seq[Expression])
     extends RS_Predicate
     with CodegenFallback {
 
@@ -137,7 +137,7 @@ case class RS_Contains(inputExpressions: Seq[Expression])
   }
 }
 
-case class RS_Within(inputExpressions: Seq[Expression])
+private[apache] case class RS_Within(inputExpressions: Seq[Expression])
     extends RS_Predicate
     with CodegenFallback {
 
