@@ -22,7 +22,13 @@ import org.apache.spark.sql.Column
 import org.apache.spark.sql.sedona_sql.expressions.collect.ST_Collect
 import org.locationtech.jts.operation.buffer.BufferParameters
 
-object st_functions extends DataFrameAPI {
+import org.apache.spark.sql.sedona_sql.DataFrameShims._
+
+object st_functions {
+  def ExpandAddress(address: Column): Column = wrapExpression[ExpandAddress](address)
+  def ExpandAddress(address: String): Column = wrapExpression[ExpandAddress](address)
+  def ParseAddress(address: Column): Column = wrapExpression[ParseAddress](address)
+  def ParseAddress(address: String): Column = wrapExpression[ParseAddress](address)
   def GeometryType(geometry: Column): Column = wrapExpression[GeometryType](geometry)
   def GeometryType(geometry: String): Column = wrapExpression[GeometryType](geometry)
 
@@ -190,6 +196,11 @@ object st_functions extends DataFrameAPI {
   def ST_Envelope(geometry: Column): Column = wrapExpression[ST_Envelope](geometry)
   def ST_Envelope(geometry: String): Column = wrapExpression[ST_Envelope](geometry)
 
+  def ST_Envelope(geography: Column, split: Boolean): Column =
+    wrapExpression[ST_Envelope](geography, split)
+  def ST_Envelope(geography: String, split: Boolean): Column =
+    wrapExpression[ST_Envelope](geography, split)
+
   def ST_Expand(geometry: Column, uniformDelta: Column) =
     wrapExpression[ST_Expand](geometry, uniformDelta)
   def ST_Expand(geometry: String, uniformDelta: String) =
@@ -629,6 +640,11 @@ object st_functions extends DataFrameAPI {
   def ST_SubDivideExplode(geometry: String, maxVertices: Int): Column =
     wrapExpression[ST_SubDivideExplode](geometry, maxVertices)
 
+  def ST_Segmentize(geometry: Column, maxSegmentLength: Column): Column =
+    wrapExpression[ST_Segmentize](geometry, maxSegmentLength)
+  def ST_Segmentize(geometry: String, maxSegmentLength: Double): Column =
+    wrapExpression[ST_Segmentize](geometry, maxSegmentLength)
+
   def ST_SimplifyPreserveTopology(geometry: Column, distanceTolerance: Column): Column =
     wrapExpression[ST_SimplifyPreserveTopology](geometry, distanceTolerance)
   def ST_SimplifyPreserveTopology(geometry: String, distanceTolerance: Double): Column =
