@@ -20,14 +20,13 @@ package org.apache.spark.sql.sedona_sql.strategy.join
 
 import org.apache.sedona.common.FunctionsGeoTools
 import org.apache.sedona.common.utils.{CachedCRSTransformFinder, GeomUtils}
+import org.geotools.api.geometry.BoundingBox
+import org.geotools.api.referencing.crs.{CoordinateReferenceSystem, GeographicCRS}
 import org.geotools.coverage.grid.GridCoverage2D
-import org.geotools.geometry.Envelope2D
-import org.geotools.geometry.jts.JTS
+import org.geotools.geometry.jts.{JTS, ReferencedEnvelope}
 import org.geotools.referencing.CRS
 import org.geotools.referencing.crs.{DefaultEngineeringCRS, DefaultGeographicCRS}
 import org.locationtech.jts.geom.{Envelope, Geometry}
-import org.opengis.geometry.BoundingBox
-import org.opengis.referencing.crs.{CoordinateReferenceSystem, GeographicCRS}
 
 object JoinedGeometryRaster {
 
@@ -63,14 +62,15 @@ object JoinedGeometryRaster {
       geom
     } else {
       val env = geom.getEnvelopeInternal
-      val envelope = new Envelope2D(null, env.getMinX, env.getMinY, env.getWidth, env.getHeight)
       val crs = FunctionsGeoTools.sridToCRS(srid)
+      val envelope =
+        new ReferencedEnvelope(env.getMinX, env.getMaxX, env.getMinY, env.getMaxY, null)
       transformToWGS84Envelope(envelope, crs)
     }
   }
 
   private def transformToWGS84Envelope(
-      envelope: org.opengis.geometry.Envelope,
+      envelope: ReferencedEnvelope,
       crs: CoordinateReferenceSystem): Geometry = {
     // We use CRS.transform for envelopes to transform envelopes between different CRSs. This transformation function
     // could handle envelope crossing the anti-meridian and envelope near or covering poles correctly. We won't have
