@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.sedona.core;
 
+import java.io.IOException;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
@@ -29,29 +29,23 @@ import org.apache.spark.SparkConf;
 import org.apache.spark.api.java.JavaSparkContext;
 import org.apache.spark.serializer.KryoSerializer;
 
-import java.io.IOException;
+public class TestBase {
+  protected static SparkConf conf;
+  protected static JavaSparkContext sc;
 
-public class TestBase
-{
-    protected static SparkConf conf;
-    protected static JavaSparkContext sc;
+  protected static void initialize(final String testSuiteName) {
+    conf = new SparkConf().setAppName(testSuiteName).setMaster("local[*]");
+    conf.set("spark.serializer", KryoSerializer.class.getName());
+    conf.set("spark.kryo.registrator", SedonaKryoRegistrator.class.getName());
 
-    protected static void initialize(final String testSuiteName)
-    {
-        conf = new SparkConf().setAppName(testSuiteName).setMaster("local[*]");
-        conf.set("spark.serializer", KryoSerializer.class.getName());
-        conf.set("spark.kryo.registrator", SedonaKryoRegistrator.class.getName());
+    sc = new JavaSparkContext(conf);
+    Logger.getLogger("org").setLevel(Level.WARN);
+    Logger.getLogger("akka").setLevel(Level.WARN);
+  }
 
-        sc = new JavaSparkContext(conf);
-        Logger.getLogger("org").setLevel(Level.WARN);
-        Logger.getLogger("akka").setLevel(Level.WARN);
-    }
-
-    protected static void deleteFile(String path)
-            throws IOException
-    {
-        Configuration hadoopConfig = new Configuration();
-        FileSystem fileSystem = FileSystem.get(hadoopConfig);
-        fileSystem.delete(new Path(path), true);
-    }
+  protected static void deleteFile(String path) throws IOException {
+    Configuration hadoopConfig = new Configuration();
+    FileSystem fileSystem = FileSystem.get(hadoopConfig);
+    fileSystem.delete(new Path(path), true);
+  }
 }
