@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.sedona.sql
 
 import org.apache.sedona.common.enums.FileDataSplitter
@@ -31,14 +30,19 @@ import org.apache.spark.sql.types._
 import org.locationtech.jts.geom.Point
 import org.scalatest.GivenWhenThen
 
-class adapterTestScala extends TestBaseScala with GivenWhenThen{
+class adapterTestScala extends TestBaseScala with GivenWhenThen {
 
   describe("Sedona-SQL Scala Adapter Test") {
 
     it("Read CSV point into a SpatialRDD") {
-      var df = sparkSession.read.format("csv").option("delimiter", "\t").option("header", "false").load(arealmPointInputLocation)
+      var df = sparkSession.read
+        .format("csv")
+        .option("delimiter", "\t")
+        .option("header", "false")
+        .load(arealmPointInputLocation)
       df.createOrReplaceTempView("inputtable")
-      var spatialDf = sparkSession.sql("select ST_PointFromText(inputtable._c0,\",\") as arealandmark from inputtable")
+      var spatialDf = sparkSession.sql(
+        "select ST_PointFromText(inputtable._c0,\",\") as arealandmark from inputtable")
       var spatialRDD = Adapter.toSpatialRdd(spatialDf, "arealandmark")
       spatialRDD.analyze()
       val resultDf = Adapter.toDf(spatialRDD, sparkSession)
@@ -46,83 +50,135 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
     }
 
     it("Read CSV point at a different column id into a SpatialRDD") {
-      var df = sparkSession.read.format("csv").option("delimiter", "\t").option("header", "false").load(arealmPointInputLocation)
+      var df = sparkSession.read
+        .format("csv")
+        .option("delimiter", "\t")
+        .option("header", "false")
+        .load(arealmPointInputLocation)
       df.createOrReplaceTempView("inputtable")
-      var spatialDf = sparkSession.sql("select \'123\', \'456\', ST_PointFromText(inputtable._c0,\",\") as arealandmark, \'789\' from inputtable")
+      var spatialDf = sparkSession.sql(
+        "select \'123\', \'456\', ST_PointFromText(inputtable._c0,\",\") as arealandmark, \'789\' from inputtable")
       var spatialRDD = Adapter.toSpatialRdd(spatialDf, 2)
       spatialRDD.analyze()
       val newDf = Adapter.toDf(spatialRDD, sparkSession)
-      assert(newDf.schema.toList.map(f => f.name).mkString("\t").equals("geometry\t123\t456\t789"))
+      assert(
+        newDf.schema.toList.map(f => f.name).mkString("\t").equals("geometry\t123\t456\t789"))
     }
 
     it("Read CSV point at a different column col name into a SpatialRDD") {
-      var df = sparkSession.read.format("csv").option("delimiter", "\t").option("header", "false").load(arealmPointInputLocation)
+      var df = sparkSession.read
+        .format("csv")
+        .option("delimiter", "\t")
+        .option("header", "false")
+        .load(arealmPointInputLocation)
       df.createOrReplaceTempView("inputtable")
-      var spatialDf = sparkSession.sql("select \'123\', \'456\', ST_PointFromText(inputtable._c0,\",\") as arealandmark, \'789\' from inputtable")
+      var spatialDf = sparkSession.sql(
+        "select \'123\', \'456\', ST_PointFromText(inputtable._c0,\",\") as arealandmark, \'789\' from inputtable")
       var spatialRDD = Adapter.toSpatialRdd(spatialDf, "arealandmark")
       spatialRDD.analyze()
       val newDf = Adapter.toDf(spatialRDD, sparkSession)
-      assert(newDf.schema.toList.map(f => f.name).mkString("\t").equals("geometry\t123\t456\t789"))
+      assert(
+        newDf.schema.toList.map(f => f.name).mkString("\t").equals("geometry\t123\t456\t789"))
     }
 
     it("Read CSV point into a SpatialRDD by passing coordinates") {
-      var df = sparkSession.read.format("csv").option("delimiter", ",").option("header", "false").load(arealmPointInputLocation)
+      var df = sparkSession.read
+        .format("csv")
+        .option("delimiter", ",")
+        .option("header", "false")
+        .load(arealmPointInputLocation)
       df.createOrReplaceTempView("inputtable")
-      var spatialDf = sparkSession.sql("select ST_Point(cast(inputtable._c0 as Decimal(24,20)),cast(inputtable._c1 as Decimal(24,20))) as arealandmark from inputtable")
+      var spatialDf = sparkSession.sql(
+        "select ST_Point(cast(inputtable._c0 as Decimal(24,20)),cast(inputtable._c1 as Decimal(24,20))) as arealandmark from inputtable")
       var spatialRDD = Adapter.toSpatialRdd(spatialDf, "arealandmark")
       assert(Adapter.toDf(spatialRDD, sparkSession).columns.length == 1)
     }
 
     it("Read mixed WKT geometries into a SpatialRDD") {
-      var df = sparkSession.read.format("csv").option("delimiter", "\t").option("header", "false").load(mixedWktGeometryInputLocation)
+      var df = sparkSession.read
+        .format("csv")
+        .option("delimiter", "\t")
+        .option("header", "false")
+        .load(mixedWktGeometryInputLocation)
       df.createOrReplaceTempView("inputtable")
-      var spatialDf = sparkSession.sql("select ST_GeomFromWKT(inputtable._c0) as usacounty from inputtable")
+      var spatialDf =
+        sparkSession.sql("select ST_GeomFromWKT(inputtable._c0) as usacounty from inputtable")
       var spatialRDD = Adapter.toSpatialRdd(spatialDf, "usacounty")
       spatialRDD.analyze()
       assert(Adapter.toDf(spatialRDD, sparkSession).columns.length == 1)
     }
 
     it("Read mixed WKT geometries into a SpatialRDD with uniqueId") {
-      var df = sparkSession.read.format("csv").option("delimiter", "\t").option("header", "false").load(mixedWktGeometryInputLocation)
+      var df = sparkSession.read
+        .format("csv")
+        .option("delimiter", "\t")
+        .option("header", "false")
+        .load(mixedWktGeometryInputLocation)
       df.createOrReplaceTempView("inputtable")
-      var spatialDf = sparkSession.sql("select ST_GeomFromWKT(inputtable._c0) as usacounty, inputtable._c3, inputtable._c5 from inputtable")
+      var spatialDf = sparkSession.sql(
+        "select ST_GeomFromWKT(inputtable._c0) as usacounty, inputtable._c3, inputtable._c5 from inputtable")
       var spatialRDD = Adapter.toSpatialRdd(spatialDf, "usacounty")
       spatialRDD.analyze()
       assert(Adapter.toDf(spatialRDD, sparkSession).columns.length == 3)
     }
 
     it("Read shapefile -> DataFrame") {
-      var spatialRDD = ShapefileReader.readToGeometryRDD(sparkSession.sparkContext, shapefileInputLocation)
+      var spatialRDD =
+        ShapefileReader.readToGeometryRDD(sparkSession.sparkContext, shapefileInputLocation)
       spatialRDD.analyze()
       var df = Adapter.toDf(spatialRDD, sparkSession)
-      assert(df.schema.toList.map(f => f.name).mkString("\t").equals("geometry\tSTATEFP\tCOUNTYFP\tCOUNTYNS\tAFFGEOID\tGEOID\tNAME\tLSAD\tALAND\tAWATER"))
+      assert(
+        df.schema.toList
+          .map(f => f.name)
+          .mkString("\t")
+          .equals(
+            "geometry\tSTATEFP\tCOUNTYFP\tCOUNTYNS\tAFFGEOID\tGEOID\tNAME\tLSAD\tALAND\tAWATER"))
       assert(df.count() == 3220)
     }
 
     it("Read shapefileWithMissing -> DataFrame") {
-      var spatialRDD = ShapefileReader.readToGeometryRDD(sparkSession.sparkContext, shapefileWithMissingsTrailingInputLocation)
+      var spatialRDD = ShapefileReader.readToGeometryRDD(
+        sparkSession.sparkContext,
+        shapefileWithMissingsTrailingInputLocation)
       spatialRDD.analyze()
       var df = Adapter.toDf(spatialRDD, sparkSession)
       assert(df.count() == 3)
     }
 
     it("Read GeoJSON to DataFrame") {
-      var spatialRDD = new PolygonRDD(sparkSession.sparkContext, geojsonInputLocation, FileDataSplitter.GEOJSON, true)
+      var spatialRDD = new PolygonRDD(
+        sparkSession.sparkContext,
+        geojsonInputLocation,
+        FileDataSplitter.GEOJSON,
+        true)
       spatialRDD.analyze()
-      var df = Adapter.toDf(spatialRDD, sparkSession)//.withColumn("geometry", callUDF("ST_GeomFromWKT", col("geometry")))
+      var df = Adapter.toDf(
+        spatialRDD,
+        sparkSession
+      ) // .withColumn("geometry", callUDF("ST_GeomFromWKT", col("geometry")))
       assert(df.columns(1) == "STATEFP")
     }
 
     it("Convert spatial join result to DataFrame") {
-      val polygonWktDf = sparkSession.read.format("csv").option("delimiter", "\t").option("header", "false").load(mixedWktGeometryInputLocation)
+      val polygonWktDf = sparkSession.read
+        .format("csv")
+        .option("delimiter", "\t")
+        .option("header", "false")
+        .load(mixedWktGeometryInputLocation)
       polygonWktDf.createOrReplaceTempView("polygontable")
-      val polygonDf = sparkSession.sql("select ST_GeomFromWKT(polygontable._c0) as usacounty, 'abc' as abc, 'def' as def from polygontable")
+      val polygonDf = sparkSession.sql(
+        "select ST_GeomFromWKT(polygontable._c0) as usacounty, 'abc' as abc, 'def' as def from polygontable")
       val polygonRDD = Adapter.toSpatialRdd(polygonDf, "usacounty")
       polygonRDD.analyze()
 
-      val pointCsvDF = sparkSession.read.format("csv").option("delimiter", ",").option("header", "false").load(arealmPointInputLocation)
+      val pointCsvDF = sparkSession.read
+        .format("csv")
+        .option("delimiter", ",")
+        .option("header", "false")
+        .load(arealmPointInputLocation)
       pointCsvDF.createOrReplaceTempView("pointtable")
-      val pointDf = sparkSession.sql("select ST_Point(cast(pointtable._c0 as Decimal(24,20)),cast(pointtable._c1 as Decimal(24,20))) as arealandmark from pointtable")
+      val pointDf = sparkSession.sql(
+        "select ST_Point(cast(pointtable._c0 as Decimal(24,20)),cast(pointtable._c1 as Decimal(24,20))) as arealandmark from pointtable")
       val pointRDD = Adapter.toSpatialRdd(pointDf, "arealandmark")
       pointRDD.analyze()
 
@@ -138,7 +194,8 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
       assert(joinResultDf.schema(0).name == "leftgeometry")
       assert(joinResultDf.schema(1).name == "rightgeometry")
       import scala.jdk.CollectionConverters._
-      val joinResultDf2 = Adapter.toDf(joinResultPairRDD, polygonRDD.fieldNames.asScala.toSeq, List(), sparkSession)
+      val joinResultDf2 =
+        Adapter.toDf(joinResultPairRDD, polygonRDD.fieldNames.asScala.toSeq, List(), sparkSession)
       assert(joinResultDf2.schema(0).dataType == GeometryUDT)
       assert(joinResultDf2.schema(0).name == "leftgeometry")
       assert(joinResultDf2.schema(1).name == "abc")
@@ -148,15 +205,25 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
     }
 
     it("Convert distance join result to DataFrame") {
-      var pointCsvDF = sparkSession.read.format("csv").option("delimiter", ",").option("header", "false").load(arealmPointInputLocation)
+      var pointCsvDF = sparkSession.read
+        .format("csv")
+        .option("delimiter", ",")
+        .option("header", "false")
+        .load(arealmPointInputLocation)
       pointCsvDF.createOrReplaceTempView("pointtable")
-      var pointDf = sparkSession.sql("select ST_Point(cast(pointtable._c0 as Decimal(24,20)),cast(pointtable._c1 as Decimal(24,20))) as arealandmark from pointtable")
+      var pointDf = sparkSession.sql(
+        "select ST_Point(cast(pointtable._c0 as Decimal(24,20)),cast(pointtable._c1 as Decimal(24,20))) as arealandmark from pointtable")
       var pointRDD = Adapter.toSpatialRdd(pointDf, "arealandmark")
       pointRDD.analyze()
 
-      var polygonWktDf = sparkSession.read.format("csv").option("delimiter", "\t").option("header", "false").load(mixedWktGeometryInputLocation)
+      var polygonWktDf = sparkSession.read
+        .format("csv")
+        .option("delimiter", "\t")
+        .option("header", "false")
+        .load(mixedWktGeometryInputLocation)
       polygonWktDf.createOrReplaceTempView("polygontable")
-      var polygonDf = sparkSession.sql("select ST_GeomFromWKT(polygontable._c0) as usacounty from polygontable")
+      var polygonDf =
+        sparkSession.sql("select ST_GeomFromWKT(polygontable._c0) as usacounty from polygontable")
       var polygonRDD = Adapter.toSpatialRdd(polygonDf, "usacounty")
       polygonRDD.analyze()
       var circleRDD = new CircleRDD(polygonRDD, 0.2)
@@ -176,7 +243,11 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
     }
 
     it("load id column Data check") {
-      var spatialRDD = new PolygonRDD(sparkSession.sparkContext, geojsonIdInputLocation, FileDataSplitter.GEOJSON, true)
+      var spatialRDD = new PolygonRDD(
+        sparkSession.sparkContext,
+        geojsonIdInputLocation,
+        FileDataSplitter.GEOJSON,
+        true)
       spatialRDD.analyze()
       val df = Adapter.toDf(spatialRDD, sparkSession)
       assert(df.columns.length == 4)
@@ -192,9 +263,17 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
       val HDFrootGroupName = "MOD_Swath_LST"
       val HDFDataVariableName = "LST"
       val urlPrefix = resourceFolder + "modis/"
-      val HDFDataVariableList:Array[String] = Array("LST", "QC", "Error_LST", "Emis_31", "Emis_32")
-      val earthdataHDFPoint = new EarthdataHDFPointMapper(HDFincrement, HDFoffset, HDFrootGroupName, HDFDataVariableList, HDFDataVariableName, urlPrefix)
-      val spatialRDD = new PointRDD(sparkSession.sparkContext, InputLocation, numPartitions, earthdataHDFPoint)
+      val HDFDataVariableList: Array[String] =
+        Array("LST", "QC", "Error_LST", "Emis_31", "Emis_32")
+      val earthdataHDFPoint = new EarthdataHDFPointMapper(
+        HDFincrement,
+        HDFoffset,
+        HDFrootGroupName,
+        HDFDataVariableList,
+        HDFDataVariableName,
+        urlPrefix)
+      val spatialRDD =
+        new PointRDD(sparkSession.sparkContext, InputLocation, numPartitions, earthdataHDFPoint)
       import scala.jdk.CollectionConverters._
       spatialRDD.fieldNames = HDFDataVariableList.dropRight(4).toList.asJava
       val spatialDf = Adapter.toDf(spatialRDD, sparkSession)
@@ -202,7 +281,8 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
     }
 
     it("can convert spatial RDD with user data to a valid Dataframe") {
-      val srcDF = sparkSession.sql("select ST_PointFromText('40.7128,-74.0060', ',') as geom, \"attr1\" as attr1, \"attr2\" as attr2")
+      val srcDF = sparkSession.sql(
+        "select ST_PointFromText('40.7128,-74.0060', ',') as geom, \"attr1\" as attr1, \"attr2\" as attr2")
       val rdd = Adapter.toSpatialRdd(srcDF, "geom")
       val df = Adapter.toDf(rdd, Seq("attr1", "attr2"), sparkSession)
       df.unpersist(true)
@@ -237,12 +317,12 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
 
       // Convert to DataFrame
       // Tweak the column names to camelCase to ensure it also renames
-      val schema = StructType(Array(
-        StructField("leftGeometry", GeometryUDT, nullable = true),
-        StructField("exampleText", StringType, nullable = true),
-        StructField("exampleDouble", DoubleType, nullable = true),
-        StructField("exampleInt", IntegerType, nullable = true)
-      ))
+      val schema = StructType(
+        Array(
+          StructField("leftGeometry", GeometryUDT, nullable = true),
+          StructField("exampleText", StringType, nullable = true),
+          StructField("exampleDouble", DoubleType, nullable = true),
+          StructField("exampleInt", IntegerType, nullable = true)))
       val rdd = Adapter.toSpatialRdd(srcDF, "geom")
       val df = Adapter.toDf(rdd, schema, sparkSession)
 
@@ -253,16 +333,17 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
       // valid external type for schema of <current data type>"
       println(df.show(1))
 
-      assert(
-        df.schema == schema,
-        s"Expected schema\n$schema\nbut got\n${df.schema}!"
-      )
+      assert(df.schema == schema, s"Expected schema\n$schema\nbut got\n${df.schema}!")
     }
 
     it("can convert JavaPairRDD to DataFrame with user-supplied schema") {
       // Prepare JavaPairRDD
       // Left table
-      val pointCsvDF = sparkSession.read.format("csv").option("delimiter", ",").option("header", "false").load(arealmPointInputLocation)
+      val pointCsvDF = sparkSession.read
+        .format("csv")
+        .option("delimiter", ",")
+        .option("header", "false")
+        .load(arealmPointInputLocation)
       pointCsvDF.createOrReplaceTempView("pointtable")
       val pointDf = sparkSession.sql("""
         select
@@ -276,7 +357,11 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
       pointRDD.analyze()
 
       // Right table
-      val polygonWktDf = sparkSession.read.format("csv").option("delimiter", "\t").option("header", "false").load(mixedWktGeometryInputLocation)
+      val polygonWktDf = sparkSession.read
+        .format("csv")
+        .option("delimiter", "\t")
+        .option("header", "false")
+        .load(mixedWktGeometryInputLocation)
       polygonWktDf.createOrReplaceTempView("polygontable")
       val polygonDf = sparkSession.sql("""
         select
@@ -321,27 +406,28 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
 
       // Convert to DataFrame
       // Tweak the column names to camelCase to ensure it also renames
-      val schema = StructType(Array(
-        StructField("leftGeometry", GeometryUDT, nullable = true),
-        StructField("exampleText", StringType, nullable = true),
-        StructField("exampleFloat", FloatType, nullable = true),
-        StructField("exampleDouble", DoubleType, nullable = true),
-        StructField("exampleShort", ShortType, nullable = true),
-        StructField("exampleInt", IntegerType, nullable = true),
-        StructField("exampleLong", LongType, nullable = true),
-        StructField("exampleBool", BooleanType, nullable = true),
-        StructField("exampleDate", DateType, nullable = true),
-        StructField("exampleTimestamp", TimestampType, nullable = true),
-        StructField("exampleStruct", StructType(Array(
-          StructField("structText", StringType, nullable = true),
-          StructField("structInt", IntegerType, nullable = true),
-          StructField("structBool", BooleanType, nullable = true)
-        ))),
-        StructField("rightGeometry", GeometryUDT, nullable = true),
-        // We have to include a column for right user data (even though there is none)
-        // since there is no way to distinguish between no data and nullable data
-        StructField("rightUserData", StringType, nullable = true)
-      ))
+      val schema = StructType(
+        Array(
+          StructField("leftGeometry", GeometryUDT, nullable = true),
+          StructField("exampleText", StringType, nullable = true),
+          StructField("exampleFloat", FloatType, nullable = true),
+          StructField("exampleDouble", DoubleType, nullable = true),
+          StructField("exampleShort", ShortType, nullable = true),
+          StructField("exampleInt", IntegerType, nullable = true),
+          StructField("exampleLong", LongType, nullable = true),
+          StructField("exampleBool", BooleanType, nullable = true),
+          StructField("exampleDate", DateType, nullable = true),
+          StructField("exampleTimestamp", TimestampType, nullable = true),
+          StructField(
+            "exampleStruct",
+            StructType(Array(
+              StructField("structText", StringType, nullable = true),
+              StructField("structInt", IntegerType, nullable = true),
+              StructField("structBool", BooleanType, nullable = true)))),
+          StructField("rightGeometry", GeometryUDT, nullable = true),
+          // We have to include a column for right user data (even though there is none)
+          // since there is no way to distinguish between no data and nullable data
+          StructField("rightUserData", StringType, nullable = true)))
       val joinResultDf = Adapter.toDf(joinResultPairRDD, schema, sparkSession)
 
       // Check results
@@ -353,21 +439,23 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
 
       assert(
         joinResultDf.schema == schema,
-        s"Expected schema\n$schema\nbut got\n${joinResultDf.schema}!"
-      )
+        s"Expected schema\n$schema\nbut got\n${joinResultDf.schema}!")
     }
 
     /**
-     * If providing fieldNames instead of a schema, it should return the same result
-     * as if we do provide a schema but declare all non-geom fields to be StringType
+     * If providing fieldNames instead of a schema, it should return the same result as if we do
+     * provide a schema but declare all non-geom fields to be StringType
      */
     it("is consistent with toDf without schema vs with all StringType fields") {
       // Prepare JavaPairRDD
       // Left table
-      val pointCsvDF = sparkSession.read.format("csv").option("delimiter", ",").option("header", "false").load(arealmPointInputLocation)
+      val pointCsvDF = sparkSession.read
+        .format("csv")
+        .option("delimiter", ",")
+        .option("header", "false")
+        .load(arealmPointInputLocation)
       pointCsvDF.createOrReplaceTempView("pointtable")
-      val pointDf = sparkSession.sql(
-        """
+      val pointDf = sparkSession.sql("""
         select
           ST_Point(
             cast(pointtable._c0 as Decimal(24,20)),
@@ -380,10 +468,13 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
       pointRDD.analyze()
 
       // Right table
-      val polygonWktDf = sparkSession.read.format("csv").option("delimiter", "\t").option("header", "false").load(mixedWktGeometryInputLocation)
+      val polygonWktDf = sparkSession.read
+        .format("csv")
+        .option("delimiter", "\t")
+        .option("header", "false")
+        .load(mixedWktGeometryInputLocation)
       polygonWktDf.createOrReplaceTempView("polygontable")
-      val polygonDf = sparkSession.sql(
-        """
+      val polygonDf = sparkSession.sql("""
         select
           ST_GeomFromWKT(polygontable._c0) as usacounty,
           'abc' as exampletext,
@@ -400,16 +491,20 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
       val joinResultPairRDD = JoinQuery.SpatialJoinQueryFlat(pointRDD, polygonRDD, true, true)
 
       // Convert to DataFrame
-      val schema = StructType(Array(
-        StructField("leftgeometry", GeometryUDT, nullable = true),
-        StructField("exampletext", StringType, nullable = true),
-        StructField("exampledouble", StringType, nullable = true),
-        StructField("exampleint", StringType, nullable = true),
-        StructField("rightgeometry", GeometryUDT, nullable = true),
-        StructField("userdata", StringType, nullable = true)
-      ))
+      val schema = StructType(
+        Array(
+          StructField("leftgeometry", GeometryUDT, nullable = true),
+          StructField("exampletext", StringType, nullable = true),
+          StructField("exampledouble", StringType, nullable = true),
+          StructField("exampleint", StringType, nullable = true),
+          StructField("rightgeometry", GeometryUDT, nullable = true),
+          StructField("userdata", StringType, nullable = true)))
       val joinResultDf = Adapter.toDf(joinResultPairRDD, schema, sparkSession)
-      val resultWithoutSchema = Adapter.toDf(joinResultPairRDD, Seq("exampletext", "exampledouble", "exampleint"), Seq("userdata"), sparkSession)
+      val resultWithoutSchema = Adapter.toDf(
+        joinResultPairRDD,
+        Seq("exampletext", "exampledouble", "exampleint"),
+        Seq("userdata"),
+        sparkSession)
 
       // Check results
       // Force an action so that spark has to serialize the data -- this will surface
@@ -420,15 +515,20 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
 
       assert(
         joinResultDf.schema == resultWithoutSchema.schema,
-        s"Schema of\n$schema\ndoes not match result from supplying field names\n${joinResultDf.schema}!"
-      )
+        s"Schema of\n$schema\ndoes not match result from supplying field names\n${joinResultDf.schema}!")
     }
 
     it("can convert spatial pair RDD with user data to a valid Dataframe") {
-      var srcDF = sparkSession.read.format("csv").option("delimiter", "\t").option("header", "false").load(mixedWktGeometryInputLocation)
+      var srcDF = sparkSession.read
+        .format("csv")
+        .option("delimiter", "\t")
+        .option("header", "false")
+        .load(mixedWktGeometryInputLocation)
       srcDF.createOrReplaceTempView("inputtable")
-      var leftDF = sparkSession.sql("select ST_GeomFromWKT(inputtable._c0) as leftGeom, \"attr1\" as attr1, \"attr2\" as attr2 from inputtable")
-      val rightDF = sparkSession.sql("select ST_PointFromText('40.7128,-74.0060', ',') as rightGeom, \"attr3\" as attr3, \"attr4\" as attr4")
+      var leftDF = sparkSession.sql(
+        "select ST_GeomFromWKT(inputtable._c0) as leftGeom, \"attr1\" as attr1, \"attr2\" as attr2 from inputtable")
+      val rightDF = sparkSession.sql(
+        "select ST_PointFromText('40.7128,-74.0060', ',') as rightGeom, \"attr3\" as attr3, \"attr4\" as attr4")
       val leftRDD = Adapter.toSpatialRdd(leftDF, "leftGeom")
       leftRDD.analyze()
       val rightRDD = Adapter.toSpatialRdd(rightDF, "rightGeom")
@@ -436,7 +536,8 @@ class adapterTestScala extends TestBaseScala with GivenWhenThen{
       leftRDD.spatialPartitioning(GridType.QUADTREE)
       rightRDD.spatialPartitioning(leftRDD.getPartitioner)
       val pairRDD = JoinQuery.SpatialJoinQueryFlat(leftRDD, rightRDD, true, true)
-      val pairDF = Adapter.toDf(pairRDD, Seq("attr1", "attr2"), Seq("attr3", "attr4"), sparkSession)
+      val pairDF =
+        Adapter.toDf(pairRDD, Seq("attr1", "attr2"), Seq("attr3", "attr4"), sparkSession)
       pairDF.unpersist(true)
       // verify the resulting Spark dataframe can be successfully evaluated repeatedly
       for (_ <- 1 to 5) {
