@@ -18,7 +18,7 @@
  */
 package org.apache.sedona.viz.sql
 
-import org.apache.sedona.viz.sql.operator.{AggregateWithinPartitons, VizPartitioner}
+import org.apache.sedona.viz.sql.operator.{AggregateWithinPartitions, VizPartitioner}
 import org.apache.sedona.viz.sql.utils.{Conf, LineageDecoder}
 import org.apache.spark.sql.functions.lit
 import org.locationtech.jts.geom.Envelope
@@ -43,7 +43,11 @@ class optVizOperatorTest extends VizTestBase {
 
       // Test aggregation within partitions
       val result =
-        AggregateWithinPartitons(newDf.withColumn("weight", lit(100.0)), "pixel", "weight", "avg")
+        AggregateWithinPartitions(
+          newDf.withColumn("weight", lit(100.0)),
+          "pixel",
+          "weight",
+          "avg")
       assert(result.rdd.getNumPartitions == secondaryPID)
 
       // Test the colorize operator
@@ -71,7 +75,7 @@ class optVizOperatorTest extends VizTestBase {
       assert(newDf.rdd.getNumPartitions == secondaryPID)
 
       // Test aggregation within partitions
-      val result = AggregateWithinPartitons(newDf, "pixel", "weight", "count")
+      val result = AggregateWithinPartitions(newDf, "pixel", "weight", "count")
       assert(result.rdd.getNumPartitions == secondaryPID)
 
       // Test the colorize operator
