@@ -20,6 +20,7 @@ package org.apache.spark.sql.execution.datasources.v2.geoparquet.metadata
 
 import org.apache.hadoop.fs.Path
 import org.apache.spark.sql.SparkSession
+import org.apache.spark.sql.catalyst.FileSourceOptions
 import org.apache.spark.sql.catalyst.expressions.Expression
 import org.apache.spark.sql.connector.read.PartitionReaderFactory
 import org.apache.spark.sql.execution.datasources.PartitioningAwareFileIndex
@@ -50,20 +51,19 @@ case class GeoParquetMetadataScan(
       sparkSession.sparkContext.broadcast(new SerializableConfiguration(hadoopConf))
     // The partition values are already truncated in `FileScan.partitions`.
     // We should use `readPartitionSchema` as the partition schema here.
+    val fileSourceOptions = new FileSourceOptions(caseSensitiveMap)
     GeoParquetMetadataPartitionReaderFactory(
       sparkSession.sessionState.conf,
       broadcastedConf,
       dataSchema,
       readDataSchema,
       readPartitionSchema,
+      fileSourceOptions,
       pushedFilters)
   }
 
+  override def isSplitable(path: Path): Boolean = false
+
   override def getFileUnSplittableReason(path: Path): String =
     "Reading parquet file metadata does not require splitting the file"
-
-  // This is for compatibility with Spark 3.0. Spark 3.3 does not have this method
-  def withFilters(partitionFilters: Seq[Expression], dataFilters: Seq[Expression]): FileScan = {
-    copy(partitionFilters = partitionFilters, dataFilters = dataFilters)
-  }
 }
